#!/usr/bin/gawk -f

BEGIN{
  # Eq. (1)
  P0 = 12.913779
#  JD0 = 2408247.968
  JD0 = 2408254.4248895  # this is shifted by 0.5P wrt. Burnasev!
  dotP = 3.87265e-6

  # JD = JD0 + P0 E + dotP E^2
  # dotP E^2 + P0 E + JD0-JD = 0
  # a x^2    + b x  + c      = 0
  # x = (-b +- sqrt(b^2 - 4ac)) / 2a

  print "# JD0 = ", sprintf("%.4f", JD0), " day"
  print "# P0 = ", P0, " day"
  print "# dotP = ", dotP, " day day^-1"

  split(".027 .066 .103 .213 .299 .333 .490 .798 .868 .949 .989", phase_burnasev);

  OFMT=CONVFMT="%.4f";
  print "# JD & E & phase & phase_burnasev";
}

(FNR>1) && (NF>1){
  JD = $1+2400000.0;
  i++;
  print JD, E(JD), phase(JD), phase_burnasev[i];
}

func x1(a,b,c) {
  return (-b + sqrt(b**2 - 4.*a*c)) / (2.*a);
}

func E(JD) {
  return x1(dotP, P0, JD0-JD);
}

func zero_(E) {
  if (E > 0) {
    return E;
  } else {
    return E+1.0;
  }
}

func phase(JD) {
  return zero_(E(JD)-int(E(JD)));
}

