#!/usr/bin/gawk -f

BEGIN{
  cm = 1.e-2;	# m
  mu = 1.e-6;	# m
  nm = 1.e-9;	# m
  Ang = 1.e-10;	# m
  erg = 1.e-7;	# J

  EB_minus_V = 0.020;
  A_V = 3.1*EB_minus_V;

  n=0;
}
(ARGIND==1) && !/^#/{
  n++;
  lambda[n] = $1*mu;
  A_lambda_A_V[n] = $2+0.0;
}
(ARGIND>1) && (FNR==2){
  print "# E(B-V) = ", EB_minus_V, " mag";
  print "# A_V = ", A_V, " mag";
}
(ARGIND>1) && /^#/{
  print;
}
(ARGIND>1) && !/^#/{
  HJD = $1;
  lambda_ = $2;
  band = $3;
  F_lambda = $4;
  sigma = $5;
  dataset = $6;
  filename = $7;

  A_lambda_A_V_ = linterp(lambda, A_lambda_A_V, n, lambda_, extra);
  A_lambda = A_lambda_A_V_ * A_V;

  mag = -2.5*log10(F_lambda);
  mag0 = mag - A_lambda;
  F_lambda0 = 10.0**(-0.4*mag0);

  printf("%.6f  %.8e  %.8e  %.8e  %.8e  %d  %s\n", HJD, lambda_, band, F_lambda0, sigma, dataset, filename);
}

function log10(x) {
  return log(x)/log(10);
}

func linterp(x,y,n,x0,extra, i,y0) {
 
  if (x0 < x[1]) {
    extra = 1;
    i = 2;
  } else if (x0 > x[n]) {
    extra = 1;
    i = n
  } else {
    extra = 0;
    i = 2
    while (x[i] < x0) {
      i++;
    }
  }

  if (x[i]==x[i-1]) {
    y0 = y[i];
  } else {
    y0 = y[i-1] + (y[i]-y[i-1]) * (x0-x[i-1])/(x[i]-x[i-1]);
  }

#  print x0,"i = ",i,x[i-1],x[i],y[i-1],y[i],y0;	# dbg

  if (extra == 1) {
    print "# Warning: Extrapolation for x0 = ", x0;
  }

  return y0;
}


